/**
 * Rozšířené atributy – program na správu rozšířených atributů souborů
 * Copyright © 2012 František Kučera (frantovo.cz)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package cz.frantovo.rozsireneAtributy.jedit;

import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.JPanel;
import javax.swing.JTextArea;
import org.gjt.sp.jedit.Buffer;
import org.gjt.sp.jedit.EBComponent;
import org.gjt.sp.jedit.EBMessage;
import org.gjt.sp.jedit.EditBus;
import org.gjt.sp.jedit.View;
import org.gjt.sp.jedit.msg.EditPaneUpdate;

/**
 *
 * @author Ing. František Kučera (frantovo.cz)
 */
public class DokovatelnyPanel extends JPanel implements EBComponent {

	private static final Logger log = Logger.getLogger(DokovatelnyPanel.class.getName());
	private JTextArea pokus = new JTextArea("...");
	private View view;

	public DokovatelnyPanel(final View view, final String position) {
		this.view = view;
		add(pokus);
	}

	/**
	 * Zaregistrujeme se, aby nám chodily události editoru.
	 */
	@Override
	public void addNotify() {
		super.addNotify();
		EditBus.addToBus(this);
	}

	/**
	 * @see #addNotify()
	 */
	@Override
	public void removeNotify() {
		super.removeNotify();
		EditBus.removeFromBus(this);
	}

	/**
	 * Zpracujeme události editoru.
	 * Zajímá nás přepnutí na jiný soubor – abychom pro něj zobrazili atributy.
	 *
	 * @param událost událost editoru
	 */
	@Override
	public void handleMessage(EBMessage událost) {
		try {
			if (událost instanceof EditPaneUpdate) {
				EditPaneUpdate epu = (EditPaneUpdate) událost;
				// Chodí nám všechny události – potřebujeme filtrovat jen ty pro naše okno.
				if (view == epu.getEditPane().getView()) {
					změňSoubor(view.getBuffer());
				}
			}
			// událost instanceof BufferUpdate
			// událost instanceof PropertiesChanged
		} catch (Exception e) {
			log.log(Level.WARNING, "Chyba při zpracování události: " + událost, e);
		}

	}

	private void změňSoubor(Buffer b) {
		pokus.setText(b.getPath());
	}
}
